Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3299)

Unified Diff: chrome/browser/autofill/android/personal_data_manager_android.h

Issue 2417353002: PaymentRequest: Rename includeName parameter to includeNameInLabel. (Closed)
Patch Set: PaymentRequest: Rename includeName parameter to includeNameInLabel. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autofill/android/personal_data_manager_android.h
diff --git a/chrome/browser/autofill/android/personal_data_manager_android.h b/chrome/browser/autofill/android/personal_data_manager_android.h
index c6d15c79fb8220d5176a4cf19df27db9c1964c4e..66e7b8c2d603ffa7793ccc6f33726bc34790ff9e 100644
--- a/chrome/browser/autofill/android/personal_data_manager_android.h
+++ b/chrome/browser/autofill/android/personal_data_manager_android.h
@@ -79,12 +79,12 @@ class PersonalDataManagerAndroid
// useful for distinguishing the profiles from one another.
//
// The labels never contain the email address, or phone numbers. The
// |include_name| argument controls whether the name is included. All other
// fields are included in the label.
base::android::ScopedJavaLocalRef<jobjectArray> GetProfileLabelsToSuggest(
JNIEnv* env,
const base::android::JavaParamRef<jobject>& unused_obj,
- jboolean include_name);
+ jboolean include_name_in_label);
// Returns the label of the given profile for PaymentRequest. This label does
// not contain the full name or the email address. All other fields are
@@ -328,7 +328,7 @@ class PersonalDataManagerAndroid
base::android::ScopedJavaLocalRef<jobjectArray> GetProfileLabels(
JNIEnv* env,
bool address_only,
- bool include_name,
+ bool include_name_in_label,
std::vector<AutofillProfile*> profiles);
// Pointer to the java counterpart.
@@ -79,12 +79,12 @@ class PersonalDataManagerAndroid
//
// The labels never contain the email address, or phone numbers. The
- // |include_name| argument controls whether the name is included. All other
- // fields are included in the label.
+ // |include_name_in_label| argument controls whether the name is included.
+ // All other fields are included in the label.
base::android::ScopedJavaLocalRef<jobjectArray> GetProfileLabelsToSuggest(
JNIEnv* env,

Powered by Google App Engine
This is Rietveld 408576698